<?php
error_reporting(E_ALL);

if (!defined('PATH_SEPARATOR')) {
	if (strtoupper(substr(PHP_OS, 0, 3)) !== 'WIN') {
		define('PATH_SEPARATOR', ':');
	} else {
		define('PATH_SEPARATOR', ';');
	}
}
set_include_path(dirname(__FILE__) . '/libs' . PATH_SEPARATOR . get_include_path());

require_once 'XML/RPC.php';
require_once 'Services/OpenSearch.php';

if (!(isset($_GET['q']) && $_GET['q'] != '')) {
	exit;
}

// はてなダイアリーキーワード連想語
$client = new XML_RPC_client('/xmlrpc', 'd.hatena.ne.jp');
$params = new XML_RPC_Value(
	array(
		'wordlist' => new XML_RPC_Value(
			array(
				new XML_RPC_Value($_GET['q'])
			),
			'array'
		)
	), 
	'struct'
);

$message = new XML_RPC_Message('hatena.getSimilarWord', array($params));
$response = $client->send($message);

if ($response && !$response->faultCode()) {
	$value = $response->value();
	$data = XML_RPC_decode($value);

	$wordlist = array_map(
		create_function(
			'$w', 
			'return sprintf("<a href=\"#\" onclick=\"submit(\'%1\$s\')\">%1\$s</a>", htmlspecialchars($w["word"]));'
		), 
		$data['wordlist']
	);
	
	if (count($wordlist) > 0) {
		$word = '[ ' . implode(' | ', $wordlist) . ' ]';
	} else {
		$word = '(連想語はありません)';
	}
	
	echo '<div id="similar-word"><p>はてなダイアリーキーワード連想語: <br />', $word, '</p></div>';
}

// OpenSearch
$url = 'http://search.hatena.ne.jp/osxml';
$os = new Services_OpenSearch($url);
$items = $os->search($_GET['q']);
$total_results = $os->getTotalResults();

if ($total_results > 0) {
	printf('<div id="result-title"><p>%s での検索結果 (%d 件中 上位 %d 件を表示)</p></div>', 
		   htmlspecialchars($_GET['q']), 
		   $total_results, 
		   $total_results >= 10 ? 10 : $total_results);

	foreach ($items as $item) {
		printf('<div class="result"><p class="title"><a href="%s">%s</a></p><p class="disc">%s</p></div>',
			$item['link'],
			$item['title'],
			isset($item['description']) ? $item['description'] : ''
		);
	}
} else {
	printf('<div id="result-title"><p>%s に該当するページが見つかりませんでした</p></div>', htmlspecialchars($_GET['q'])); 
}
?>
